<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_Member
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_Member extends Moc10_Form
{

    /**
     * Form templates
     * @var string
     */
    protected $_template = null;

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('plugin' => null,
                                   'site_id' => null,
                                   'email' => null,
                                   'username' => null,
                                   'password1' => null,
                                   'password2' => null,
                                   'fname' => null,
                                   'lname' => null,
                                   'organization' => null,
                                   'title' => null,
                                   'address1' => null,
                                   'address2' => null,
                                   'city' => null,
                                   'state' => null,
                                   'zip' => null,
                                   'country' => null,
                                   'phone' => null,
                                   'birth_date_month' => null,
                                   'birth_date_day' => null,
                                   'birth_date_year' => null,
                                   'gender' => null,
                                   'verified' => 'Yes',
                                   'approved' => 'Yes',
                                   'receive' => 'Yes',
                                   'send_creds' => null,
                                   'member_id' => 0);

    /**
     * Initialization method for the member form.
     *
     * @param  array $post
     * @return void
     */
    public function init($post = null)
    {

        $lang = new Phire_Language();

        $this->_setFields($post);
        $this->_setTemplates();

        $this->setAttributes('id', 'addMemberForm');
        $this->setAttributes('onsubmit', "return addMemberFrm.validate();");

        // Create the 'site_id' form element.
        $site_id = new Moc10_Form_Element_Select('site_id', Phire_Sites::getAllowedSites(), $this->_postFields['site_id']);
        $site_id->setLabel($lang->__('Add to Site:'));

        // Create the 'email' form element.
        $email = new Moc10_Form_Element('text', 'email', $this->_postFields['email']);
        $email->setLabel($lang->__('Email:'));
        $email->addValidator('Email');
        $email->setAttributes('size', '40');
        $email->setRequired(true);

        // If form has been submitted, validate email.
        if (!is_null($this->_postFields['email'])) {
            $dupe_em = new Phire_Table_Members();
            $dupe_em->findBy('email', $this->_postFields['email']);
            if (isset($dupe_em->member_id) && ($dupe_em->member_id != $this->_postFields['member_id'])) {
                $email->addValidator('NotEqual', true, $dupe_em->email, $lang->__('That email already exists.'));
            }
        }

        // Create the 'username' form element.
        $username = new Moc10_Form_Element('text', 'username', $this->_postFields['username']);
        $username->setLabel($lang->__('Username:'));
        $username->setAttributes('size', '40');

        // Create the 'pass1' form element.
        $password1 = new Moc10_Form_Element('password', 'password1', $this->_postFields['password1']);
        $password1->setLabel($lang->__('Password:'));
        $password1->addValidator('LengthGT', true, 5);
        $password1->setAttributes('size', '20');

        // Create the 'pass2' form element.
        $password2 = new Moc10_Form_Element('password', 'password2', $this->_postFields['password2']);
        $password2->setLabel($lang->__('Re-type Password:'));
        $password2->addValidator('LengthGT', true, 5);
        $password2->setAttributes('size', '20');

        // If form has been submitted, validate username and password.
        if (!is_null($this->_postFields['username'])) {
            $username->addValidator('AlphaNum');
            $username->addValidator('LengthGT', true, 3);
            $dupe_user = new Phire_Table_Members();
            $dupe_user->findBy('username', $this->_postFields['username']);
            if (isset($dupe_user->member_id) && ($dupe_user->member_id != $this->_postFields['member_id'])) {
                $username->addValidator('NotEqual', true, $dupe_user->username, $lang->__('That username already exists.'));
            }
            if ($this->_postFields['password1'] != '') {
                $password2->setRequired(true);
                $password2->addValidator('Equal', true, $this->_postFields['password1'], $lang->__('The passwords do not match.'));
            }
        }

        // Create the 'fname' form element.
        $fname = new Moc10_Form_Element('text', 'fname', $this->_postFields['fname']);
        $fname->setLabel($lang->__('First Name:'));
        $fname->setAttributes('size', '40');
        $fname->setRequired(true);

        // Create the 'lname' form element.
        $lname = new Moc10_Form_Element('text', 'lname', $this->_postFields['lname']);
        $lname->setLabel($lang->__('Last Name:'));
        $lname->setAttributes('size', '40');

        // Create the 'organization' form element.
        $organization = new Moc10_Form_Element('text', 'organization', $this->_postFields['organization']);
        $organization->setLabel($lang->__('Company/Organization:'));
        $organization->setAttributes('size', '40');

        // Create the 'title' form element.
        $title = new Moc10_Form_Element('text', 'title', $this->_postFields['title']);
        $title->setLabel($lang->__('Title:'));
        $title->setAttributes('size', '40');

        // Create the 'address1' form element.
        $address1 = new Moc10_Form_Element('text', 'address1', $this->_postFields['address1']);
        $address1->setLabel($lang->__('Address 1:'));
        $address1->setAttributes('size', '40');

        // Create the 'address2' form element.
        $address2 = new Moc10_Form_Element('text', 'address2', $this->_postFields['address2']);
        $address2->setLabel($lang->__('Address 2:'));
        $address2->setAttributes('size', '40');

        // Create the 'city' form element.
        $city = new Moc10_Form_Element('text', 'city', $this->_postFields['city']);
        $city->setLabel($lang->__('City:'));
        $city->setAttributes('size', '25');

        // Create the 'state' form element.
        $state = new Moc10_Form_Element('text', 'state', $this->_postFields['state']);
        $state->setAttributes('size', '25');
        $state->setLabel($lang->__('State/Province/County:'));

        // Create the 'zip' form element.
        $zip = new Moc10_Form_Element('text', 'zip', $this->_postFields['zip']);
        $zip->setLabel($lang->__('Zip/Postal Code:'));
        $zip->setAttributes('size', '25');

        // Create the 'country' form element.
        $country = new Moc10_Form_Element_Select('country', 'COUNTRIES', $this->_postFields['country']);
        $country->setLabel($lang->__('Country:'));

        // Create the 'phone' form element.
        $phone = new Moc10_Form_Element('text', 'phone', $this->_postFields['phone']);
        $phone->setLabel($lang->__('Phone:'));
        $phone->setAttributes('size', '25');

        $months = array('--' => '--------',
                        '01' => $lang->__('January'),
                        '02' => $lang->__('February'),
                        '03' => $lang->__('March'),
                        '04' => $lang->__('April'),
                        '05' => $lang->__('May'),
                        '06' => $lang->__('June'),
                        '07' => $lang->__('July'),
                        '08' => $lang->__('August'),
                        '09' => $lang->__('September'),
                        '10' => $lang->__('October'),
                        '11' => $lang->__('November'),
                        '12' => $lang->__('December'));

        // Create the 'birth_date_month' form element.
        $birth_date_month = new Moc10_Form_Element_Select('birth_date_month', $months, $this->_postFields['birth_date_month']);
        $birth_date_month->setLabel($lang->__('Birth Date:'));

        // Create the 'birth_date_day' form element.
        $birth_date_day = new Moc10_Form_Element_Select('birth_date_day', 'DAYS_OF_MONTH', $this->_postFields['birth_date_day']);

        // Create the 'birth_date_year' form element.
        $birth_date_year = new Moc10_Form_Element_Select('birth_date_year', 'YEAR_1900', $this->_postFields['birth_date_year']);

        // Create the 'gender' form element.
        $gender = new Moc10_Form_Element_Select('gender', array('----' => '----', 'Male' => $lang->__('Male'), 'Female' => $lang->__('Female')), $this->_postFields['gender']);
        $gender->setLabel($lang->__('Gender:'));

        // Create the 'receive' form element.
        $receive = new Moc10_Form_Element_Radio('receive', array('Yes' => $lang->__('Yes'), 'No' => $lang->__('No')), $this->_postFields['receive']);
        $receive->setLabel($lang->__('Receive Updates:'));

        // Create the 'verified' form element.
        $verified = new Moc10_Form_Element_Radio('verified', array('Yes' => $lang->__('Yes'), 'No' => $lang->__('No')), $this->_postFields['verified']);
        $verified->setLabel($lang->__('Verified:'));

        // Create the 'approved' form element.
        $approved = new Moc10_Form_Element_Radio('approved', array('Yes' => $lang->__('Yes'), 'No' => $lang->__('No')), $this->_postFields['approved']);
        $approved->setLabel($lang->__('Approved:'));

        // Create the 'send_creds' form element.
        $send_creds = new Moc10_Form_Element_Checkbox('send_creds', array('send_creds' => $lang->__('Send credentials to member?')), $this->_postFields['send_creds']);

        // Create the 'member_id' form element.
        $member_id = new Moc10_Form_Element('hidden', 'member_id', $this->_postFields['member_id']);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('SAVE'));
        $submit->setAttributes('class', 'submitBtn');
        $submit->setAttributes('style', 'float: left;');

        // Set the form template and add the form element objects to the form.
        $this->setTemplate($this->_template);
        $this->addElements(array($site_id, $username, $email, $password1, $password2, $fname, $lname, $organization, $title, $address1, $address2, $city, $state, $zip, $country, $phone, $verified, $approved, $birth_date_month, $birth_date_day, $birth_date_year, $gender, $receive, $submit, $send_creds, $member_id));

    }

    /**
     * Method to save the member data.
     *
     * @return void
     */
    public function saveData()
    {

        $lang = new Phire_Language();

        $site = new Phire_Table_Sites();
        $site->getSite($this->_postFields['site_id']);

        if (($this->_postFields['birth_date_month'] == '--') || ($this->_postFields['birth_date_day'] == '--') || ($this->_postFields['birth_date_year'] == '----')) {
            $birth_date = '0000-00-00';
        } else {
            $birth_date = $this->_postFields['birth_date_year'] . '-' . $this->_postFields['birth_date_month'] . '-' . $this->_postFields['birth_date_day'];
        }

        $gender = ($this->_postFields['gender'] == '----') ? '' : $this->_postFields['gender'];

        // Edit existing member.
        if ($this->_postFields['member_id'] != 0) {
            $member = new Phire_Table_Members();
            $member->findById($this->_postFields['member_id']);

            if ($this->_postFields['password1'] != '') {
                $pass = (($site->member_password_encoding == 'On') ? sha1($this->_postFields['password1']) : $this->_postFields['password1']);
            } else {
                $pass = $member->password;
                $this->_postFields['password1'] = $member->password;
            }

            $member->site_id = $this->_postFields['site_id'];
            $member->email = $this->_postFields['email'];
            $member->username = $this->_postFields['username'];
            $member->password = $pass;
            $member->fname = $this->_postFields['fname'];
            $member->lname = $this->_postFields['lname'];
            $member->organization = $this->_postFields['organization'];
            $member->title = $this->_postFields['title'];
            $member->address1 = $this->_postFields['address1'];
            $member->address2 = $this->_postFields['address2'];
            $member->city = $this->_postFields['city'];
            $member->state = $this->_postFields['state'];
            $member->zip = $this->_postFields['zip'];
            $member->gender = $gender;
            $member->birth_date = $birth_date;
            $member->receive_updates = $this->_postFields['receive'];
            $member->country = ($this->_postFields['country'] == '--') ? '' : $this->_postFields['country'];
            $member->phone = $this->_postFields['phone'];
            $member->verified = $this->_postFields['verified'];
            $member->approved = $this->_postFields['approved'];

        // Else, add new member.
        } else {

            $fields = array('site_id' => $this->_postFields['site_id'],
                            'username' => $this->_postFields['username'],
                            'password' => (($site->member_password_encoding == 'On') ? sha1($this->_postFields['password1']) : $this->_postFields['password1']),
                            'email' => $this->_postFields['email'],
                            'verified' => $this->_postFields['verified'],
                            'approved' => $this->_postFields['approved'],
                            'fname' => $this->_postFields['fname'],
                            'lname' => $this->_postFields['lname'],
                            'organization' => $this->_postFields['organization'],
                            'title' => $this->_postFields['title'],
                            'address1' => $this->_postFields['address1'],
                            'address2' => $this->_postFields['address2'],
                            'city' => $this->_postFields['city'],
                            'state' => $this->_postFields['state'],
                            'zip' => $this->_postFields['zip'],
                            'country' => ($this->_postFields['country'] == '--') ? '' : $this->_postFields['country'],
                            'phone' => $this->_postFields['phone'],
                            'birth_date' => $birth_date,
                            'gender' => $gender,
                            'receive_updates' => $this->_postFields['receive'],
                            'last_login' => '0000-00-00 00:00:00',
                            'last_ip' => '');


            $member = new Phire_Table_Members($fields);
        }

        $member->save();

        // Else, if 'send credentials' was checked, build and send the credentials email.
        if (isset($this->_postFields['send_creds']) && ($this->_postFields['username'] != '') && ($this->_postFields['password1'] != '')) {

            $name = '';
            if ($this->_postFields['fname'] != '') {
                $name = $this->_postFields['fname'];
                if ($this->_postFields['lname'] != '') {
                    $name .= ' ' . $this->_postFields['lname'];
                }
            } else if ($this->_postFields['username'] != '') {
                $name = $this->_postFields['username'];
            } else {
                $name = $this->_postFields['email'];
            }

            $rcpt = array(array('name' => $name,
                                'email' => $member->email,
                                'username' => $member->username,
                                'password' => $this->_postFields['password1'],
                                'login_link' => 'http://' . $site->site_domain . BASE_PATH . '/member/login'));

            if ($this->_postFields['member_id'] != 0) {
                $subject = $site->site_domain . ' ' . $lang->__('Member Account Modified');
                $message = "[{name}],\n\n" . $lang->__('Your member account for %1 has been modified', $site->site_domain) . " " . $lang->__('Your credentials are:') . "\n\n" . $lang->__('Username:') . " [{username}]\n" . $lang->__('Password:') . " [{password}]\n\n" . $lang->__('You can log in here:') . "\n[{login_link}]\n\n" . $lang->__('Thank You,') . "\n\n" . $lang->__('The %1 Team', $site->site_domain) . "\n\n";
            } else {
                $subject = $site->site_domain . ' ' . $lang->__('Member Account Created');
                $message = "[{name}],\n\n" . $lang->__('Your member account for %1 has been created', $site->site_domain) . " " . $lang->__('Your credentials are:') . "\n\n" . $lang->__('Username:') . " [{username}]\n" . $lang->__('Password:') . " [{password}]\n\n" . $lang->__('You can log in here:') . "\n[{login_link}]\n\n" . $lang->__('Thank You,') . "\n\n" . $lang->__('The %1 Team', $site->site_domain) . "\n\n";
            }

            $site_domain = str_replace('www.', '', $site->site_domain);

            $mail = new Moc10_Mail($rcpt, null, $subject);
            $mail->setHeaders(array('From' => array('noreply@' . $site_domain, 'noreply@' . $site_domain),
                                    'Reply-To' => array('noreply@' . $site_domain, 'noreply@' . $site_domain)));

            $mail->setText($message);
            $mail->init();
            $mail->send();

        }

    }

    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @return void
     */
    protected function _setFields($post = null)
    {

        if (!is_null($post)) {
            if ((!$_POST) && isset($post['member_id']) && ($post['member_id'] != 0)) {

                $member = new Phire_Table_Members();
                $member->findById($post['member_id']);

                if ($member->birth_date != '0000-00-00') {
                    $birthDate = explode('-', $member->birth_date);
                } else {
                    $birthDate = array(null, null, null);
                }

                $this->_postFields['site_id'] = $member->site_id;
                $this->_postFields['email'] = $member->email;
                $this->_postFields['username'] = $member->username;
                $this->_postFields['password1'] = null;
                $this->_postFields['password2'] = null;
                $this->_postFields['fname'] = $member->fname;
                $this->_postFields['lname'] = $member->lname;
                $this->_postFields['organization'] = $member->organization;
                $this->_postFields['title'] = $member->title;
                $this->_postFields['address1'] = $member->address1;
                $this->_postFields['address2'] = $member->address2;
                $this->_postFields['city'] = $member->city;
                $this->_postFields['state'] = $member->state;
                $this->_postFields['zip'] = $member->zip;
                $this->_postFields['country'] = $member->country;
                $this->_postFields['phone'] = $member->phone;
                $this->_postFields['birth_date_month'] = $birthDate[1];
                $this->_postFields['birth_date_day'] = $birthDate[2];
                $this->_postFields['birth_date_year'] = $birthDate[0];
                $this->_postFields['gender'] = $member->gender;
                $this->_postFields['verified'] = $member->verified;
                $this->_postFields['approved'] = $member->approved;
                $this->_postFields['receive'] = $member->receive_updates;
                $this->_postFields['send_creds'] = (isset($post['send_creds'])) ? $post['send_creds'] : null;
                $this->_postFields['plugin'] = (isset($post['plugin'])) ? $post['plugin'] : null;
                $this->_postFields['member_id'] = $member->member_id;

            } else {
                foreach ($post as $key => $value) {
                    if (array_key_exists($key, $this->_postFields)) {
                        $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                    }
                }
            }
        }

    }

    /**
     * Method to set the form templates.
     *
     * @return void
     */
    protected function _setTemplates()
    {

        $lang = new Phire_Language();

        if (!is_null($this->_postFields['plugin'])) {
            $plugin = "<input type=\"hidden\" name=\"plugin\" value=\"{$this->_postFields['plugin']}\" />";
            $plg_lnk = BASE_PATH . CONTENT_PATH . "/extensions/plugins/{$this->_postFields['plugin']}/?sys_path=" . BASE_PATH . SYS_PATH;
            $plg_cancel = "&plugin={$this->_postFields['plugin']}";
        } else {
            $plugin = null;
            $plg_lnk = './members.php';
            $plg_cancel = null;
        }

        $back = $lang->__('Back');
        $mbr_info = $lang->__('Member Information');
        $contact_info = $lang->__('Contact Information');
        $biz_info = $lang->__('Business Information');
        $per_info = $lang->__('Personal Information');
        $sending = $lang->__('Sending the credentials to the member requires both the server&#39;s PHP mail function and SMTP mail agent to be configured correctly.');
        $cancel = $lang->__('CANCEL');

        // Define the main form template.
        $this->_template = <<<FORMTEMP
            <style type="text/css">
                .radioPad {
                    float: left;
                    margin: 0;
                    padding: 0 18px 0 4px;
                }
            </style>
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="{$plg_lnk}">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader">
                    <td class="grayHeader">
                        <strong style="padding-left: 25px;">{$mbr_info}</strong>
                    </td>
                </tr>
                <tr>
                    <td style="padding: 15px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td class="textTopRight">
                                    <br />
                                    [{site_id_label}]
                                </td>
                                <td>
                                    <br />
                                    [{site_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{email_label}]
                                </td>
                                <td>
                                    [{email}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{username_label}]
                                </td>
                                <td>
                                    [{username}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{password1_label}]
                                </td>
                                <td>
                                    [{password1}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{password2_label}]
                                </td>
                                <td>
                                    [{password2}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{verified_label}]
                                </td>
                                <td>
                                    [{verified}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{approved_label}]
                                </td>
                                <td>
                                    [{approved}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{receive_label}]
                                </td>
                                <td>
                                    [{receive}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="2" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <strong style="font-size: 0.85em;">{$contact_info}</strong>
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    <br />
                                    [{fname_label}]
                                </td>
                                <td>
                                    <br />
                                    [{fname}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{lname_label}]
                                </td>
                                <td>
                                    [{lname}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{address1_label}]
                                </td>
                                <td>
                                    [{address1}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{address2_label}]
                                </td>
                                <td>
                                    [{address2}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{city_label}]
                                </td>
                                <td>
                                    [{city}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{state_label}]
                                </td>
                                <td>
                                    [{state}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{zip_label}]
                                </td>
                                <td>
                                    [{zip}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{country_label}]
                                </td>
                                <td>
                                    [{country}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{phone_label}]<br /><br /><br />
                                </td>
                                <td>
                                    [{phone}]<br /><br /><br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="2" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <strong style="font-size: 0.85em;">{$biz_info}</strong>
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    <br />
                                    [{organization_label}]
                                </td>
                                <td>
                                    <br />
                                    [{organization}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{title_label}]<br /><br /><br />
                                </td>
                                <td>
                                    [{title}]<br /><br /><br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="2" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <strong style="font-size: 0.85em;">{$per_info}</strong>
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    <br />
                                    [{birth_date_month_label}]
                                </td>
                                <td>
                                    <br />
                                    [{birth_date_month}]
                                    [{birth_date_day}]
                                    [{birth_date_year}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{gender_label}]
                                </td>
                                <td>
                                    [{gender}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    &nbsp;
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    [{send_creds}]
                                    <em style="font-size: 0.85em;">{$sending}</em>
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    [{submit}] [{member_id}] <a style="margin: 0 0 0 10px; padding-top: 6px; height: 19px; font-size: 0.825em; float: left;" class="submitGrayBtn" href="../core/process/add.member.php?action=cancel{$plg_cancel}">{$cancel}</a> {$plugin}
                                </td>
                            </tr>
                        </table>
                        <script type="text/javascript">
                            addMemberFormInit();
                        </script>
                    </td>
                </tr>
            </table>
FORMTEMP;

    }

}
