<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_MemberForgot
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1
 */

class Phire_Form_MemberForgot extends Moc10_Form
{

    /**
     * Initialization method for the member forgot form.
     *
     * @param  string $em
     * @return void
     */
    public function init($em = null)
    {

        $em = (string)Moc10_String::setString($em)->escape()->striptags();
        $lang = new Phire_Language();

        $this->setAttributes('id', 'memberForm');

        // Create the 'email' form element.
        $email = new Moc10_Form_Element('text', 'email', $em);
        $email->setLabel($lang->__('Email:'));
        $email->addValidator('Email');
        $email->setAttributes('size', '40');
        $email->setRequired(true);

        // If the form has been submitted, verify the email.
        if (!is_null($em)) {
            $member_exist = new Phire_Table_Members();
            $member_exist->findBy('email', $em);
            if (!isset($member_exist->member_id)) {
                $email->addValidator('NotEqual', true, $em, $lang->__("That email doesn't exist."));
            }
        }

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('SEND'));
        $submit->setAttributes('class', 'submitBtn');

        $please = $lang->__('Please enter your email address, and a password reminder will be sent.');

        // Define the form template.
        $tmpl = <<<FORMTEMP
            <table id="memberTable">
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td>
                        <span style="font-size: 0.85em;">{$please}</span>
                    </td>
                </tr>
                <tr>
                    <td style="text-align: right; vertical-align: top;">
                        [{email_label}]
                    </td>
                    <td>
                        [{email}]
                    </td>
                </tr>
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td>
                        [{submit}]
                    </td>
                </tr>
            </table>
            <script type="text/javascript">
                document.getElementById('email').focus();
            </script>
FORMTEMP;

        // Set the form template and add the form element objects to the form.
        $this->setTemplate($tmpl);
        $this->addElements(array($email, $submit));

    }

}
