<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_PageSearch
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_PageSearch extends Moc10_Form
{

    /**
     * Initialization method for the page search form.
     *
     * @param string $pg_tle
     * @param string|int $sid
     * @param string|int $sec_id
     * @param string|int $uid
     * @param string $pub
     * @param string $acc
     * @return void
     */
    public function init($pg_tle = null, $sid = 0, $sec_id = 0, $uid = 0, $pub = null, $acc = null)
    {

        $lang = new Phire_Language();

        $this->setAttributes('id', 'pageSearchForm');

        $sess = Moc10_Session::getInstance();
        $siteAry = array('0' => $lang->__('All')) + Phire_Sites::getAllowedSites();

        // Create the 'site_id' form element.
        $site_id = new Moc10_Form_Element_Select('site_id', $siteAry, $sid);
        $site_id->setLabel($lang->__('Site:'));
        $site_id->setAttributes('style', 'min-width: 150px;');

        // Get sections.
        $sects = new Phire_Table_Sections();
        $sects->findAll('section_id ASC');
        $sectAry = array('0' => $lang->__('All'));

        foreach ($sects->rows as $sect) {
            if (in_array($sect->site_id, $sess->sites)) {
                $sectAry[$sect->section_id] = $sect->section_title;
            }
        }

        // Create the 'sect_id' form element.
        $sect_id = new Moc10_Form_Element_Select('sect_id', $sectAry, $sec_id);
        $sect_id->setLabel($lang->__('Section:'));
        $sect_id->setAttributes('style', 'min-width: 150px;');

        // Get users.
        $users = new Phire_Table_Users();
        $users->findAll('user_id ASC');
        $userAry = array('0' => $lang->__('All'));

        foreach ($users->rows as $user) {
            $userAry[$user->user_id] = $user->fname . ' ' . $user->lname;
        }

        // Create the 'user_id' form element.
        $user_id = new Moc10_Form_Element_Select('user_id', $userAry, $uid);
        $user_id->setLabel($lang->__('Author:'));
        $user_id->setAttributes('style', 'min-width: 150px;');

        // Create the 'page_title' form element.
        $page_title = new Moc10_Form_Element('text', 'page_title', $pg_tle);
        $page_title->setLabel($lang->__('Page Title:'));
        $page_title->setAttributes('size', '20');
        $page_title->setAttributes('style', 'min-width: 150px;');

        // Create the 'published' form element.
        $published = new Moc10_Form_Element_Select('published', array('Any' => $lang->__('Any'), 'No' => $lang->__('No'), 'Yes' => $lang->__('Yes'), 'Draft' => $lang->__('Draft')), $pub);
        $published->setLabel($lang->__('Published:'));
        $published->setAttributes('style', 'min-width: 150px;');

        // Create the 'access' form element.
        $access = new Moc10_Form_Element_Select('access', array('Any' => $lang->__('Any'), 'Public' => $lang->__('Public'), 'Private' => $lang->__('Private')), $acc);
        $access->setLabel($lang->__('Access:'));
        $access->setAttributes('style', 'min-width: 150px;');

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('Search'));
        $submit->setAttributes('class', 'submitGrayBtn');

        $empty = $lang->__('Submit an empty search to clear.');

        // Define the form template.
        $tmpl = <<<FORMTEMP
            <table id="pageSearchTable" cellspacing="0" cellpadding="0">
                <tr>
                    <td style="font-size: 0.9em; padding: 0 2px 0 0; text-align: right;">
                        [{page_title_label}]
                    </td>
                    <td>
                        [{page_title}]
                    </td>
                    <td style="font-size: 0.9em; padding: 0 2px 0 15px; text-align: right;">
                        [{site_id_label}]
                    </td>
                    <td>
                        [{site_id}]
                    </td>
                    <td style="font-size: 0.9em; padding: 0 2px 0 15px; text-align: right;">
                        [{sect_id_label}]
                    </td>
                    <td>
                        [{sect_id}]
                    </td>
                </tr>
                <tr>
                    <td style="font-size: 0.9em; padding: 0 2px 0 15px; text-align: right;">
                        [{user_id_label}]
                    </td>
                    <td>
                        [{user_id}]
                    </td>
                    <td style="font-size: 0.9em; padding: 0 2px 0 15px; text-align: right;">
                        [{published_label}]
                    </td>
                    <td>
                        [{published}]
                    </td>
                    <td style="font-size: 0.9em; padding: 0 2px 0 15px; text-align: right;">
                        [{access_label}]
                    </td>
                    <td>
                        [{access}]
                    </td>
                    <td style="padding: 0 2px 0 15px; text-align: left;">
                        [{submit}]
                    </td>
                </tr>
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td colspan="6" style="padding: 10px 2px 0 0; text-align: left;">
                        <em style="font-size: 0.9em;">({$empty})</em>
                    </td>
                </tr>
            </table>
FORMTEMP;

        // Set the form template and add the form element objects to the form.
        $this->setTemplate($tmpl);
        $this->addElements(array($site_id, $sect_id, $user_id, $page_title, $published, $access, $submit));

    }

    /**
     * Initialization method for the mobile page search form.
     *
     * @param string $pg_tle
     * @param string $pub
     * @return void
     */
    public function mobileInit($pg_tle = null, $pub = null)
    {

        $lang = new Phire_Language();

        $this->setAttributes('id', 'pageSearchForm');

        // Create the 'page_title' form element.
        $page_title = new Moc10_Form_Element('text', 'page_title', $pg_tle);
        $page_title->setLabel($lang->__('Page Title:'));
        $page_title->setAttributes('size', '20');
        $page_title->setAttributes('style', 'min-width: 150px;');

        // Create the 'published' form element.
        $published = new Moc10_Form_Element_Select('published', array('Any' => $lang->__('Any'), 'No' => $lang->__('No'), 'Yes' => $lang->__('Yes'), 'Draft' => $lang->__('Draft')), $pub);
        $published->setLabel($lang->__('Published:'));
        $published->setAttributes('style', 'min-width: 150px;');

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', strtoupper($lang->__('Search')));
        $submit->setAttributes('class', 'submitBtnGray');

        $empty = $lang->__('Submit an empty search to clear.');

        // Define the form template.
        $tmpl = <<<FORMTEMP
            <table id="pageSearchTable" cellspacing="0" cellpadding="0">
                <tr>
                    <td style="font-size: 0.9em; padding: 0 2px 0 0; text-align: right; width: 33%">
                        [{page_title_label}]
                    </td>
                    <td>
                        [{page_title}]
                    </td>
                </tr>
                <tr>
                    <td style="font-size: 0.9em; padding: 0 2px 0 15px; text-align: right;">
                        [{published_label}]
                    </td>
                    <td>
                        [{published}]
                    </td>
                </tr>
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td>
                        [{submit}]
                    </td>
                </tr>
                <tr>
                    <td colspan="2" style="padding-top: 10px;">
                        <em style="font-size: 0.9em;">({$empty})</em>
                    </td>
                </tr>
            </table>
FORMTEMP;

        // Set the form template and add the form element objects to the form.
        $this->setTemplate($tmpl);
        $this->addElements(array($page_title, $published, $submit));

    }

}
