<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Parser
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Parser_Date
 *
 * @category   Phire
 * @package    Phire_Parser
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Parser_Date
{

    /**
     * Date matches
     * @var array
     */
    protected $_matches = array();

    /**
     * Date RegEx
     * @var string
     */
    protected $_regex = '/\[\{date.*\}\]/';

    /**
     * Content to evaluate
     * @var string
     */
    protected $_content = null;

    /**
     * URL request
     * @var string
     */
    protected $_url = null;

    /**
     * Constructor
     *
     * Instantiate the date parser object.
     *
     * @param  string $content
     * @param  string $url
     * @return void
     */
    public function __construct($content, $url = null)
    {

        // Perform a preg_match_all to look for any date tags within the content, then parse the content.
        $this->_content = $content;
        preg_match_all($this->_regex, $this->_content, $this->_matches);
        $this->_parse();

    }

    /**
     * Static method to instantiate the date parser object
     * and return the parsed string.
     *
     * @param  string $cont
     * @param  string $u
     * @return Phire_Parser_Date
     */
    public static function init($cont, $u = null)
    {

        return new self($cont, $u);

    }

    /**
     * Set content within the content property.
     *
     * @param  string $subject
     * @param  string $replace
     * @return void
     */
    public function setContent($subject, $replace)
    {

        $this->_content = str_replace($subject, $replace, $this->_content);

    }

    /**
     * Get content within the content property.
     *
     * @return string
     */
    public function getContent()
    {

        return $this->_content;

    }

    /**
     * Renders any date elements within the content.
     *
     * @return void
     */
    protected function _parse()
    {

        // If date tag elements are found, format and set in content.
        if (isset($this->_matches[0][0])) {

            foreach ($this->_matches[0] as $value) {
                if ($value == '[{date}]') {
                    $site = new Phire_Table_Sites();
                    $site->getSite();
                    if ($site->default_date_format != '') {
                        $date_format = ($site->default_time_format != '') ? $site->default_date_format . ' ' . $site->default_time_format : $site->default_date_format;
                    } else {
                        $date_format = 'm/d/Y';
                    }
                } else {
                    $dte = str_replace('[{', '', $value);
                    $dte = str_replace('}]', '', $dte);
                    $dteFmtAry = explode('_', $dte);
                    $date_format = (isset($dteFmtAry[2])) ? $dteFmtAry[1] . ' ' . $dteFmtAry[2] : $dteFmtAry[1];
                }
                $this->setContent($value, date($date_format));
            }

        }

    }

}
