<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Video
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Video
 *
 * @category   Phire
 * @package    Phire_Video
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Video extends Phire_Template
{

    /**
     * Video ID
     * @var string
     */
    protected $_video_id = null;

    /**
     * Video type
     * @var string
     */
    protected $_video_type = null;

    /**
     * YouTube template
     * @var string
     */
    protected $_youtube_tmpl = "        <object width=\"425\" height=\"344\">\n            <param name=\"movie\" value=\"http://www.youtube.com/v/[{video_id}]\"></param>\n            <param name=\"allowFullScreen\" value=\"true\"></param>\n            <param name=\"wmode\" value=\"transparent\"></param>\n            <param name=\"allowscriptaccess\" value=\"always\"></param>\n            <embed src=\"http://www.youtube.com/v/[{video_id}]\" type=\"application/x-shockwave-flash\" allowscriptaccess=\"always\" wmode=\"transparent\" allowfullscreen=\"true\" width=\"425\" height=\"344\"></embed>\n        </object>";

    /**
     * Vimeo template
     * @var string
     */
    protected $_vimeo_tmpl = "        <object width=\"400\" height=\"300\">\n            <param name=\"allowfullscreen\" value=\"true\" />\n            <param name=\"allowscriptaccess\" value=\"always\" />\n            <param name=\"wmode\" value=\"transparent\" />\n            <param name=\"movie\" value=\"http://vimeo.com/moogaloop.swf?clip_id=[{video_id}]&amp;server=vimeo.com&amp;show_title=1&amp;show_byline=1&amp;show_portrait=0&amp;color=&amp;fullscreen=1\" />\n            <embed src=\"http://vimeo.com/moogaloop.swf?clip_id=[{video_id}]&amp;server=vimeo.com&amp;show_title=1&amp;show_byline=1&amp;show_portrait=0&amp;color=&amp;fullscreen=1\" type=\"application/x-shockwave-flash\" allowfullscreen=\"true\" wmode=\"transparent\" allowscriptaccess=\"always\" width=\"400\" height=\"300\"></embed>\n        </object>";

    /**
     * Vimeo template
     * @var string
     */
    protected $_viddler_tmpl = "        <object classid=\"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000\" width=\"437\" height=\"370\" id=\"viddler_[{video_id}]\">\n            <param name=\"movie\" value=\"http://www.viddler.com/player/[{video_id}]/\" />\n            <param name=\"allowScriptAccess\" value=\"always\" />\n            <param name=\"wmode\" value=\"transparent\" />\n            <param name=\"allowFullScreen\" value=\"true\" />\n            <embed src=\"http://www.viddler.com/player/[{video_id}]/\" width=\"437\" height=\"370\" type=\"application/x-shockwave-flash\" allowScriptAccess=\"always\" wmode=\"transparent\" allowFullScreen=\"true\" name=\"viddler_[{video_id}]\"></embed>\n        </object>";

    /**
     * Site object
     * @var Phire_Table_Site
     */
    protected $_site = null;

    /**
     * Constructor
     *
     * Instantiate the video object.
     *
     * @param  string $url
     * @return void
     */
    public function __construct($url)
    {

        parent::__construct();
        $this->_tmpl = Phire_Parser::getParser($this->_tmpl, $url)->getContent();

        $urlParts = Moc10_String::setString($url)->split('/');

        $this->_video_type = (isset($urlParts[2]) ? $urlParts[2] : '');
        $this->_video_id = (isset($urlParts[3]) ? $urlParts[3] : '');

        // Get the site information.
        $this->_site = new Phire_Table_Sites();
        $this->_site->getSite();

        $this->setContent('[{page_charset}]', $this->_site->charset);
        $this->setContent('[{page_author}]', Moc10_String::setString($this->_site->default_author)->strip()->html());
        $this->setContent('[{page_keywords}]', Moc10_String::setString($this->_site->default_keywords)->strip()->html());
        $this->setContent('[{page_desc}]', Moc10_String::setString($this->_site->default_desc)->strip()->html());
        $this->setContent('[{page_robots}]', $this->_site->robots);
        $this->setContent('[{site_domain}]', $this->_site->site_domain);
        $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . 'Video')->strip()->html());
        $this->setContent('[{page_sub_title}]', 'Video');
        $this->setContent('[{base_path}]', BASE_PATH);
        $this->setContent('[{sys_path}]', SYS_PATH);
        $this->setContent('[{content_path}]', CONTENT_PATH);

        // Set video template within the content.
        if ($this->_video_type == 'youtube') {
            $this->setContent('[{page_content}]', $this->_youtube_tmpl);
        } else if ($this->_video_type == 'vimeo') {
            $this->setContent('[{page_content}]', $this->_vimeo_tmpl);
        } else if ($this->_video_type == 'viddler') {
            $this->setContent('[{page_content}]', $this->_viddler_tmpl);
        }

        $this->setContent('[{video_id}]', $this->_video_id);

    }

}
