<?php

/**
 * Phire Bulk Pages
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

require_once '../../bootstrap.php';

try {

    // Get the pages to process.
    $bulk_pages = array();
    $bulk_pages = $_POST['bulk_pages'];

    if (isset($bulk_pages[0])) {

        foreach ($bulk_pages as $value) {

            $page = new Phire_Table_Pages();
            $page->findById($value);

            $site = new Phire_Table_Sites();
            $site->findById($page->site_id);

            // If an action is set, process the pages accordingly.
            if (isset($_POST['action_id'])) {

                if ($_POST['select_action'] == 'published') {
                    $page->published = $_POST['action_id'];
                    $page->updated = date('Y-m-d H:i:s');
                    $page->save();
                    $action = 'saved';
                } else if ($_POST['select_action'] == 'access') {
                    $page->page_access = $_POST['action_id'];
                    $page->updated = date('Y-m-d H:i:s');
                    $page->save();
                    $action = 'saved';
                }

                if (isset($site->site_id) && ($site->page_caching == 'On')) {

                    // Get Page.
                    $pg = new Phire_Page($page->page_id, $site->site_id, true);
                    $pg->init();

                    // Get page content type from template.
                    $tmpl = new Phire_Table_Templates();
                    $tmpl->join(DB_PREFIX . 'content_types', 'type_id', null, 'template_id', $page->template_id, 1);

                    // Get section access, if applicable.
                    if ($page->section_id != 0) {
                        $sect = new Phire_Table_Sections();
                        $sect->findById($page->section_id);
                        $section_access = $sect->section_access;
                    } else {
                        $section_access = 'Public';
                    }

                    // Get SSL settings for page and site.
                    $page_ssl = ($page->force_ssl_connection == 'Yes') ? 443 : 80;
                    $site_ssl = ($site->use_ssl_connection == 'Yes') ? 443 : 80;

                    $cache_file_headers = $tmpl->rows[0]['type'] . "|" . $page->page_access . '_' . $section_access . "|" . $page_ssl . '_' . $site_ssl . '|' . $page->published . '_' . $site->site_live . '|' . $site->site_id . "\n";

                    $filename = $site->site_docroot . BASE_PATH . CONTENT_PATH . '/cache/' . sha1($page->page_url) . '.txt';
                    $cache_file = new Moc10_File($filename);
                    $cache_file->write($cache_file_headers . $pg->getPage());

                    if ($tmpl->mobile_template != '') {
                        $mob_filename = $site->site_docroot . BASE_PATH . CONTENT_PATH . '/cache/mobile/' . sha1($page->page_url) . '.txt';
                        $mob_cache_file = new Moc10_File($mob_filename);
                        $mob_cache_file->write($cache_file_headers . $pg->getMobilePage());
                    }

                }

            // Else, remove the selected pages.
            } else {

                $site = new Phire_Table_Sites();
                $site->findById($page->site_id);

                // Remove the cache file if it exists.
                $cache_file = $site->site_docroot . BASE_PATH . CONTENT_PATH . '/cache/' . sha1($page->page_url) . '.txt';
                if (file_exists($cache_file)) {
                    unlink($cache_file);
                }

                $page->delete();
                $action = 'removed';

            }

        }

        $sess = Moc10_Session::getInstance();
        unset($sess->pages);

        if (isset($_POST['plugin'])) {
            header('Location: ' . BASE_PATH . CONTENT_PATH . '/extensions/plugins/' . $_POST['plugin'] .'/?action=' . $action . '&sys_path=' . BASE_PATH . SYS_PATH);
        } else {
            $pages = new Phire_Table_Pages();
            $pages->findAll();

            $cfg = new Phire_Table_Config();
            $result = count($pages->rows) / $cfg->settings['system_pagination_limit'];
            $goToPage = ($result > 1) ? '&page=' . ceil($result) : null;
            header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'content/pages.php?action=' . $action . $goToPage);
        }

    } else {

        if (isset($_POST['plugin'])) {
            header('Location: ' . BASE_PATH . CONTENT_PATH . '/extensions/plugins/' . $_POST['plugin'] .'/&sys_path=' . BASE_PATH . SYS_PATH);
        } else {
            $pages = new Phire_Table_Pages();
            $pages->findAll();

            $cfg = new Phire_Table_Config();
            $result = count($pages->rows) / $cfg->settings['system_pagination_limit'];
            $goToPage = ($result > 1) ? '?page=' . ceil($result) : null;
            header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'content/pages.php' . $goToPage);
        }

    }

// Else throw a exception/error.
} catch (Exception $e) {

    include_once 'init.php';
    include_once '../includes/error.header.php';
    print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 0 0;\">" . $e->getMessage() . "</p>\n");
    include_once '../includes/footer.php';

}

?>
