<?php

/**
 * Phire Import Members
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

set_time_limit(0);
require_once '../../bootstrap.php';

try {

    // Retrieve session and check if the import members action has been cancelled, clearing out any related session data.
    $sess = Moc10_Session::getInstance();

    if ((isset($_GET['action'])) && ($_GET['action'] == 'cancel')) {

        unset($sess->csv_file_error);
        unset($sess->import_members_form);

        if (isset($_GET['plugin'])) {
            header('Location: ' . BASE_PATH . CONTENT_PATH . '/extensions/plugins/' . $_GET['plugin'] . '/?sys_path=' . BASE_PATH . SYS_PATH);
        } else {
            header('Location: ' . BASE_PATH . SYS_PATH . '/system/members.php');
        }

    // Else, get the POST data and validate the form.
    } else {

        unset($sess->import_members_form);
        unset($sess->csv_file_error);

        $file = (isset($_FILES['csv_file']['name']) ? $_FILES['csv_file']['name'] : null);

        $form = new Phire_Form_ImportMembers(BASE_PATH . SYS_PATH . '/core/process/import.members.php', 'post', '        ');
        $form->init($_POST, $file);

        // If the form is valid, process the new CSV file.
        if ($form->isValid()) {

            try {

                // Upload the new CSV file, changing the permissions.
                $csv_file = new Moc10_File_Upload($_FILES['csv_file']['tmp_name'], $_SERVER['DOCUMENT_ROOT'] . BASE_PATH . CONTENT_PATH . '/' . $_FILES['csv_file']['name'], null, array('csv'  => 'text/csv'));
                $csv_file->setMode(0777);

                // Import the member data into an array and delete the CSV file.
                $csv_members_array = $csv_file->import();
                $csv_file->delete();

                // Set the member count and the allowed member fields.
                $mem_count = 0;
                $mem_fields = array('site_id', 'username', 'password', 'email', 'lname', 'fname', 'address1', 'address2', 'city', 'state', 'zip', 'country', 'phone', 'organization', 'title', 'birth_date', 'gender', 'verified', 'approved', 'receive_updates', 'last_login', 'last_ip');

                $members = array();

                $site = new Phire_Table_Sites();
                $site->getSite($_POST['site_id']);

                // Iterate through each imported member and the member data, cleaning up and initializing the data where applicable.
                if (isset($csv_members_array[0])) {

                    foreach ($csv_members_array as $member) {

                        foreach ($member as $key => $value) {
                            if (!in_array($key, $mem_fields)) {
                                unset($member[$key]);
                            }
                        }

                        foreach ($mem_fields as $value) {

                            if (!array_key_exists($value, $member)) {

                                switch ($value) {

                                    case 'verified':
                                        $member[$value] = 'Yes';
                                        break;

                                    case 'approved':
                                        $member[$value] = 'Yes';
                                        break;

                                    case 'receive_updates':
                                        $member[$value] = 'Yes';
                                        break;

                                    case 'birth_date':
                                        $member[$value] = '0000-00-00';
                                        break;

                                    case 'last_login':
                                        $member[$value] = '0000-00-00 00:00:00';
                                        break;

                                    case 'site_id':
                                        $member[$value] = $_POST['site_id'];
                                        break;

                                    default:
                                        $member[$value] = '';

                                }

                            }

                        }

                        $dupe_member = false;

                        // Verify if the username is already in the system.
                        if ($member['username'] != '') {
                            $dupe_user = new Phire_Table_Members();
                            $dupe_user->findBy('username', $member['username']);
                            if (isset($dupe_user->member_id)) {
                                $dupe_member = true;
                            }
                        }

                        // Verify if the email is already in the system.
                        if ($member['email'] != '') {
                            $dupe_email = new Phire_Table_Members();
                            $dupe_email->findBy('email', $member['email']);
                            if (isset($dupe_email->member_id)) {
                                $dupe_member = true;
                            }
                        }

                        // If the member is valid, save to the system.
                        if (($dupe_member == false) && ($member['email'] != '') && ($member['fname'] != '')) {

                            $members[] = $member;

                            if (($site->member_password_encoding == 'On') && ($member['password'] != '')) {
                                $member['password'] = sha1($member['password']);
                            }

                            $new_member = new Phire_Table_Members($member);
                            $new_member->save();
                            $mem_count++;

                        }

                    }

                }

                // If 'send credentials' was checked, build and send the credentials email.
                if (isset($_POST['send_creds'])) {

                    $rcpts = array();

                    foreach ($members as $member) {
                        if (($member['username'] != '') && ($member['password'] != '')) {
                            $name = '';
                            if ($member['fname'] != '') {
                                $name = $member['fname'];
                                if ($member['lname'] != '') {
                                    $name .= ' ' . $member['lname'];
                                }
                            } else if ($member['username'] != '') {
                                $name = $member['username'];
                            } else {
                                $name = $member['email'];
                            }
                            $rcpts[] = array('name' => $name,
                                             'email' => $member['email'],
                                             'username' => $member['username'],
                                             'password' => $member['password'],
                                             'login_link' => 'http://' . $site->site_domain . BASE_PATH . '/member/login');
                        }
                    }

                    $message = "[{name}],\n\n" . $lang->__('Your member account for %1 has been created.', $site->site_domain) . " " . $lang->__('Your credentials are:') . "\n\n" . $lang->__('Username:') . " [{username}]\n" . $lang->__('Password:') . " [{password}]\n\n" . $lang->__('You can log in here:') . "\n[{login_link}]\n\n" . $lang->__('Thank You,') . "\n\n" . $lang->__('The %1 Team', $site->site_domain) . "\n\n";
                    $site_domain = str_replace('www.', '', $site->site_domain);

                    // Build and send the email(s).
                    if (isset($rcpts[0])) {

                        $mail = new Moc10_Mail($rcpts, null, $site->site_domain . ' ' . $lang->__('Member Account Created'));
                        $mail->setHeaders(array('From' => array('noreply@' . $site_domain, 'noreply@' . $site_domain),
                                                'Reply-To' => array('noreply@' . $site_domain, 'noreply@' . $site_domain)));

                        $mail->setText($message);
                        $mail->init();
                        $mail->send();

                    }

                }

                // Return to the plugins page.
                if ((isset($_POST['plugin'])) && (!is_null($_POST['plugin']))) {
                    header('Location: ' . BASE_PATH . CONTENT_PATH . '/extensions/plugins/' . $_POST['plugin'] .'/?action=added&sys_path=' . BASE_PATH . SYS_PATH . '&count=' . $mem_count);
                // Else, return to the members page.
                } else {
                    header('Location: ' . BASE_PATH . SYS_PATH . '/system/members.php?action=added&count=' . $mem_count);
                }

            // Else, set file error and return to the form.
            } catch (Exception $e) {
                $sess->csv_file_error = "<div class=\"error\" style=\"margin-left: 2.5%; padding: 10px;\">" . $lang->__('There was an error uploading your CSV file.') . " " . $e->getMessage() . "</div>\n";
                $sess->import_members_form = $form;
                header('Location: ' . BASE_PATH . SYS_PATH . '/system/import-members.php');
            }

        // Else, set the form into a session variable and return.
        } else {
            $sess->import_members_form = $form;
            header('Location: ' . BASE_PATH . SYS_PATH . '/system/import-members.php');
        }

    }

// Else throw a exception/error.
} catch (Exception $e) {

    include_once 'init.php';
    include_once '../includes/error.header.php';
    print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 0 0;\">" . $e->getMessage() . "</p>\n");
    include_once '../includes/footer.php';

}

?>
