<?php

/**
 * Phire Install Complete
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

require_once '../bootstrap.php';
require_once '../core/process/install.check.php';
include_once '../core/process/init.php';

if ($sys_check == false) {

    include_once '../core/includes/failed.php';

// Else, process the install complete page.
} else {

    $sess = Moc10_Session::getInstance();

    // Check install pass 2.
    if ($sess->install_check != 'pass2') {

        unset($sess->install_check);
        header('Location: ' . BASE_PATH . SYS_PATH . '/install/');

    // Else, detect if the correct DB schema has been installed.
    } else if (in_array(DB_PREFIX . 'users', Moc10_Db::getInstance()->interface->getTables())) {

        $user = new Phire_Table_Users();
        $user->findById(1001);

        // Detect if the first system user has already been configured.
        if (isset($user->user_id)) {

            unset($sess->install_check);
            header('Location: ' . BASE_PATH . SYS_PATH . '/install/');

        // Else, render the setup form.
        } else {

            try {

                include_once '../core/process/init.php';
                include_once '../core/includes/install.header.php';

                // Declare the setup form.
                $form = new Phire_Form_Setup($_SERVER['PHP_SELF'], 'post', '        ');

                // If, the setup form was submitted, validate the form and finalize the setup.
                if ($_POST) {

                    $form->init($_POST);

                    // Confirm successful setup.
                    if ($form->isValid()) {

                        print("        <h2 class=\"blueHeader\">" . $lang->__('Install') . " &gt; " . $lang->__('Complete!') . "</h2>\n");
                        $form->saveData();
                        print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 150px 0;\">" . $lang->__('The installation has successfully completed. You can %1log in here%2 to start using the system, or view the default site %3here%4.', array("<a href=\"" . BASE_PATH . SYS_PATH . "/\">", "</a>", "<a href=\"" . BASE_PATH . "/\" target=\"_blank\">", "</a>")) . "</p>\n");

                    // Else, re-render the invalid setup form with errors.
                    } else {

                        print("        <h2 class=\"blueHeader\">" . $lang->__('Install') . " &gt; " . $lang->__('Step 2') . " &gt; " . $lang->__('Initial User Setup') . "</h2>\n");
                        print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 10px 0;\">" . $lang->__('The database schema was successfully installed. Please finalize the installation by setting up the first system user below.') . "</p>\n");
                        $form->render();

                    }

                // Else, render the new setup form.
                } else {

                    print("        <h2 class=\"blueHeader\">" . $lang->__('Install') . " &gt; " . $lang->__('Step 2') . " &gt; " . $lang->__('Setup Initial User') . "</h2>\n");
                    print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 10px 0;\">" . $lang->__('The database schema was successfully installed. Please finalize the installation by setting up the first system user below.') . "</p>\n");
                    $form->init();
                    $form->render();

                }

                include_once '../core/includes/footer.php';

            } catch (Exception $e) {

                include_once '../core/process/init.php';
                include_once '../core/includes/error.header.php';
                print("            <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 150px 0;\">" . $e->getMessage() . "</p>\n");
                include_once '../core/includes/footer.php';

            }

        }

    }

}

?>