<?php

/**
 * Phire Install Setup
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

require_once '../bootstrap.php';
require_once '../core/process/install.check.php';
include_once '../core/process/init.php';

if ($sys_check == false) {

    include_once '../core/includes/failed.php';

// Else, process the install setup page.
} else {

    $sess = Moc10_Session::getInstance();

    // Check install pass 1.
    if ($sess->install_check != 'pass1') {

        unset($sess->install_check);
        header('Location: ' . BASE_PATH . SYS_PATH . '/install/');

    // Else, check if the database schema has already been installed.
    } else if (in_array(DB_PREFIX . 'config', Moc10_Db::getInstance()->interface->getTables())) {

        unset($sess->install_check);
        header('Location: ' . BASE_PATH . SYS_PATH . '/install/');

    // Else, continue with the installation setup.
    } else {

        $mysqlVersionAry = array();
        $configAry = array();

        try {

            // Create a DB connection, read the system schema and insert it into the DB.
            $db = Moc10_Db::getInstance();

            // Create the base DB tables.
            $tables = new Moc10_File_Dir('schemas/table/');

            foreach ($tables->files as $value) {
                if (!is_dir('schemas/table/' . $value)) {
                    $table = new Moc10_File('schemas/table/' . $value);
                    if ($table->ext == 'sql') {
                        $sql = str_replace('[{db_prefix}]', DB_PREFIX, $table->read());
                        $db->interface->query($sql);
                    }
                }
            }

            // Insert base system data into the DB tables.
            $inserts = new Moc10_File_Dir('schemas/insert/');

            foreach ($inserts->files as $value) {
                if (!is_dir('schemas/insert/' . $value)) {
                    $insert = new Moc10_File('schemas/insert/' . $value);
                    if ($insert->ext == 'sql') {
                        $sql = str_replace('[{db_prefix}]', DB_PREFIX, $insert->read());
                        $db->interface->query($sql);
                    }
                }
            }

            // Detect server OS and software versions.
            $server = new Moc10_Session_Server();
            $mysqlVersionAry = explode('-', $db->interface->version());

            // Set the base system configuration.
            $configAry['system_version'] = '1.1.2';
            $configAry['system_docroot'] = $_SERVER['DOCUMENT_ROOT'];
            $configAry['server_os'] = ($server->distro != 'Unknown') ? $server->os . ' (' . $server->distro . ')' : $server->os;
            $configAry['server_software'] = $server->software;
            $configAry['mysql_version'] = trim(str_ireplace('mysql', '', $mysqlVersionAry[0]));
            $configAry['php_version'] = $server->php;
            $configAry['installed_on'] = date('Y-m-d H:i:s');
            $configAry['default_language'] = (isset($_GET['language'])) ? $_GET['language'] : 'en';

            // Save the system config data in the DB.
            foreach ($configAry as $key => $value) {
                $config = new Phire_Table_Config();
                $config->findById($key);
                $config->value = $value;
                $config->save();
            }

            // Install phone home statistics.
            $curl_url = 'http://www.phirecms.org/updates/stats.php?action=install&dom=' . base64_encode($_SERVER['HTTP_HOST']) . '&sys=' . base64_encode($configAry['system_version']) . '&os=' . base64_encode($configAry['server_os']) . '&serv=' . base64_encode($configAry['server_software']) . '&mysql=' . base64_encode($configAry['mysql_version']) . '&php=' . base64_encode($configAry['php_version']) . '&lang=' . base64_encode($configAry['default_language']);
            $options = array(CURLOPT_URL => $curl_url,
                             CURLOPT_HEADER => FALSE);
            $curl = new Moc10_Curl($options);
            $curl->execute();
            unset($curl);

            // Continue on to finalize the system install.
            $sess->install_check = 'pass2';
            header('Location: ' . BASE_PATH . SYS_PATH . '/install/complete.php');

        } catch (Exception $e) {

            include_once '../core/process/init.php';
            include_once '../core/includes/error.header.php';
            print("            <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 10px 0;\">" . $e->getMessage() . "</p>\n");
            include_once '../core/includes/footer.php';

        }

    }

}

?>