<?php

/**
 * Phire Mobile Select Site
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

require_once '../bootstrap.php';
require_once '../core/process/system.check.php';
include_once '../core/process/init.php';
require_once '../core/process/mobile/session.site.check.php';

// If the system is not properly configured or installed.
if ($sys_check == false) {

    include_once '../core/includes/failed.php';

// Else, process the site select page.
} else {

    // If there is only one site in the system, set the current site and redirect to the index page.
    if (count($sess->sites) == 1) {

        $site = new Phire_Table_Sites();
        $site->findById($sess->sites[0]);
        $sess->cur_site_id = $site->site_id;
        $sess->cur_site_domain = $site->site_domain;

        // If the previous session expired, re-route the new session to the last url.
        if (isset($sess->expire_last_url)) {
            $last_url = $sess->expire_last_url;
            unset($sess->expire_last_url);
            header('Location: ' . $last_url);
        // Else, if a previous page attempt occured, re-route to the attempted url.
        } else if (isset($sess->attempted_url)) {
            $attempted_url = $sess->attempted_url;
            unset($sess->attempted_url);
            header('Location: ' . $attempted_url);
        // Else, go the index page.
        } else {
            header('Location: ' . BASE_PATH . SYS_PATH . '/mobile/');
        }

    // Else, render the select site form.
    } else {

        $form = new Phire_Form_SelectSite($_SERVER['PHP_SELF'], 'post', '        ');

        // If the select site form has been submitted, validate it.
        if ($_POST) {

            $form->init();

            // If valid, set the current site and redirect to the index page.
            if ($form->isValid()) {

                $site = new Phire_Table_Sites();
                $site->findById($_POST['site_id']);
                $sess->cur_site_id = $site->site_id;
                $sess->cur_site_domain = $site->site_domain;

                // If the previous session expired, re-route the new session to the last url.
                if (isset($sess->expire_last_url)) {
                    $last_url = $sess->expire_last_url;
                    unset($sess->expire_last_url);
                    header('Location: ' . $last_url);
                // Else, if a previous page attempt occured, re-route to the attempted url.
                } else if (isset($sess->attempted_url)) {
                    $attempted_url = $sess->attempted_url;
                    unset($sess->attempted_url);
                    header('Location: ' . $attempted_url);
                // Else, go the index page.
                } else {
                    header('Location: ' . BASE_PATH . SYS_PATH . '/mobile/');
                }

            // Else, re-render the select site form with errors.
            } else {

                include_once '../core/includes/mobile/header.php';
                $form->render();
                include_once '../core/includes/mobile/footer.php';
            }

        // Else, render the new select site form.
        } else {

            include_once '../core/includes/mobile/header.php';
            $ste_id = (isset($sess->cur_site_id)) ? $sess->cur_site_id : 0;
            $form->init($ste_id);
            $form->render();
            include_once '../core/includes/mobile/footer.php';

        }

    }

}

?>